==> zio-aws-rds_2.12-5.17.178.1-sources.jar: zio/aws/rds/model/SourceType.scala <==
package zio.aws.rds.model
import scala.jdk.CollectionConverters._
sealed trait SourceType {
  def unwrap: software.amazon.awssdk.services.rds.model.SourceType
}
object SourceType {
  def wrap(
      value: software.amazon.awssdk.services.rds.model.SourceType
  ): zio.aws.rds.model.SourceType = value match {
    case software.amazon.awssdk.services.rds.model.SourceType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.rds.model.SourceType.DB_INSTANCE =>
      val r = `db-instance`
      r
    case software.amazon.awssdk.services.rds.model.SourceType.DB_PARAMETER_GROUP =>
      val r = `db-parameter-group`
      r
    case software.amazon.awssdk.services.rds.model.SourceType.DB_SECURITY_GROUP =>
      val r = `db-security-group`
      r
    case software.amazon.awssdk.services.rds.model.SourceType.DB_SNAPSHOT =>
      val r = `db-snapshot`
      r
    case software.amazon.awssdk.services.rds.model.SourceType.DB_CLUSTER =>
      val r = `db-cluster`
      r
    case software.amazon.awssdk.services.rds.model.SourceType.DB_CLUSTER_SNAPSHOT =>
      val r = `db-cluster-snapshot`
      r
    case software.amazon.awssdk.services.rds.model.SourceType.CUSTOM_ENGINE_VERSION =>
      val r = `custom-engine-version`
      r
    case software.amazon.awssdk.services.rds.model.SourceType.DB_PROXY =>
      val r = `db-proxy`
      r
  }
  case object unknownToSdkVersion extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.UNKNOWN_TO_SDK_VERSION
  }
  case object `db-instance` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.DB_INSTANCE
  }
  case object `db-parameter-group` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.DB_PARAMETER_GROUP
  }
  case object `db-security-group` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.DB_SECURITY_GROUP
  }
  case object `db-snapshot` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.DB_SNAPSHOT
  }
  case object `db-cluster` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.DB_CLUSTER
  }
  case object `db-cluster-snapshot` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.DB_CLUSTER_SNAPSHOT
  }
  case object `custom-engine-version` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.CUSTOM_ENGINE_VERSION
  }
  case object `db-proxy` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.DB_PROXY
  }
}

==> zio-aws-rds_2.12-6.20.78.1-sources.jar: zio/aws/rds/model/SourceType.scala <==
package zio.aws.rds.model
import scala.jdk.CollectionConverters._
sealed trait SourceType {
  def unwrap: software.amazon.awssdk.services.rds.model.SourceType
}
object SourceType {
  def wrap(
      value: software.amazon.awssdk.services.rds.model.SourceType
  ): zio.aws.rds.model.SourceType = value match {
    case software.amazon.awssdk.services.rds.model.SourceType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.rds.model.SourceType.DB_INSTANCE =>
      val r = `db-instance`
      r
    case software.amazon.awssdk.services.rds.model.SourceType.DB_PARAMETER_GROUP =>
      val r = `db-parameter-group`
      r
    case software.amazon.awssdk.services.rds.model.SourceType.DB_SECURITY_GROUP =>
      val r = `db-security-group`
      r
    case software.amazon.awssdk.services.rds.model.SourceType.DB_SNAPSHOT =>
      val r = `db-snapshot`
      r
    case software.amazon.awssdk.services.rds.model.SourceType.DB_CLUSTER =>
      val r = `db-cluster`
      r
    case software.amazon.awssdk.services.rds.model.SourceType.DB_CLUSTER_SNAPSHOT =>
      val r = `db-cluster-snapshot`
      r
    case software.amazon.awssdk.services.rds.model.SourceType.CUSTOM_ENGINE_VERSION =>
      val r = `custom-engine-version`
      r
    case software.amazon.awssdk.services.rds.model.SourceType.DB_PROXY =>
      val r = `db-proxy`
      r
    case software.amazon.awssdk.services.rds.model.SourceType.BLUE_GREEN_DEPLOYMENT =>
      val r = `blue-green-deployment`
      r
  }
  case object unknownToSdkVersion extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.UNKNOWN_TO_SDK_VERSION
  }
  case object `db-instance` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.DB_INSTANCE
  }
  case object `db-parameter-group` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.DB_PARAMETER_GROUP
  }
  case object `db-security-group` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.DB_SECURITY_GROUP
  }
  case object `db-snapshot` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.DB_SNAPSHOT
  }
  case object `db-cluster` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.DB_CLUSTER
  }
  case object `db-cluster-snapshot` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.DB_CLUSTER_SNAPSHOT
  }
  case object `custom-engine-version` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.CUSTOM_ENGINE_VERSION
  }
  case object `db-proxy` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.DB_PROXY
  }
  case object `blue-green-deployment` extends zio.aws.rds.model.SourceType {
    override def unwrap: software.amazon.awssdk.services.rds.model.SourceType =
      software.amazon.awssdk.services.rds.model.SourceType.BLUE_GREEN_DEPLOYMENT
  }
}
